<?php

declare(strict_types=1);

namespace Drupal\log_middleware\Middleware;

/**
 * Interface for log middleware.
 */
interface LogMiddlewareInterface {

  /**
   * Alter a log message.
   *
   * All references can be directly altered.
   *
   * @param string $channel
   *   The channel the log has been sent to.
   * @param mixed $level
   *   Reference to the log level.
   * @param string|\Stringable $message
   *   Reference to the log message.
   * @param array $context
   *   Reference to the log message context.
   *
   * @return LogMiddlewareResult
   *   If the result is `::Next` then the next middleware is
   *   run or the message is processed if all middleware has been run.
   *   If the result is `::DiscardMessage` then the message is
   *   discarded and not logged.
   */
  public function alterLog(string $channel, mixed &$level, string|\Stringable &$message, array &$context): LogMiddlewareResult;

}
